# -*- coding: utf-8 -*-
from setuphelpers import *
import platform

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = "BGInfo"
app_name = "BGInfo"
app_binx86 = "BGInfo.exe"
app_binx64 = "BGInfo64.exe"
app_dir = makepath(programfiles, app_name)
launch_path = makepath(startup(common=1), "BGInfo.lnk")
launch_arg = r' /accepteula "%s\tis-default.bgi" /timer:0' % app_dir


def install():
    # Initializing variables
    package_version = control.version.split("-")[0]
    bin_latest_zip = glob.glob("*%s*.zip" % bin_contains)[0]
    app_name = control.name

    # Getting installed software version
    if iswin64:
        app_bin = app_binx64
    else:
        app_bin = app_binx86
    app_bin_path = makepath(app_dir, app_bin)

    if isfile(app_bin_path):
        installed_version = get_version_from_binary(app_bin_path)
    else:
        installed_version = None

    # Installing the package
    print("Installing: %s" % app_name)
    if installed_version is None or installed_version < package_version or force:
        killalltasks(control.get_impacted_process_list())
        if isdir(app_dir):
            remove_tree(app_dir)
        mkdirs(app_dir)
        print("Extract %s to %s " % (bin_latest_zip, app_dir))
        unzip(bin_latest_zip, app_dir)
        filecopyto("tis-default.bgi", app_dir)

        # Create shortcut on start menu
        create_shortcut(launch_path, app_bin_path, launch_arg)
        # create_desktop_shortcut(app_name,app_bin_path)
        create_programs_menu_shortcut(app_name, app_bin_path)

        # Adding this package to the "list-registry"
        register_windows_uninstall(control)  # control is a PackageEntry object corresponding to this package
        register_uninstall(app_name, icon=app_bin_path)
    else:
        print("%s portable version is already installed in the correct version" % app_name)


def uninstall():
    # Uninstalling software
    killalltasks(control.get_impacted_process_list())
    unregister_uninstall(app_name)

    # Removing shortcuts
    remove_desktop_shortcut(app_name)
    remove_programs_menu_shortcut(app_name)

    # Remove folder and auto start
    if isdir(app_dir):
        remove_tree(app_dir)

    if isfile(launch_path):
        remove_file(launch_path)


def audit():
    # Declaring local variables
    package_version = control.get_software_version()
    # Getting installed software version
    if iswin64:
        app_bin = app_binx64
    else:
        app_bin = app_binx86
    app_bin_path = makepath(app_dir, app_bin)

    # Getting installed software version
    if isfile(app_bin_path):
        installed_version = get_version_from_binary(app_bin_path)
    else:
        installed_version = None

    # Auditing software
    print("Auditing: %s" % control.package)
    if installed_version is None or installed_version < package_version:
        print("%s version is incorrect (%s)" % (app_name, installed_version))
        return "ERROR"
    else:
        print("%s is installed in correct version (%s)" % (app_name, installed_version))
        return "OK"


def update_package():
    # Initializing variables
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    url_dl = "https://download.sysinternals.com/files/BGInfo.zip"
    bin_latest_zip = url_dl.split("/")[-1]
    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if isfile(bin_latest_zip):
        remove_file(bin_latest_zip)

    print("Downloading: %s" % bin_latest_zip)
    wget(url_dl, bin_latest_zip, proxies=proxies)

    # Unzip
    unzip(bin_latest_zip)

    # Changing version of the package
    version = get_version_from_binary(makepath(app_name, app_binx86))
    control.version = "%s-%s" % (version, control.version.split("-", 1)[-1])
    control.save_control_to_wapt()
    print("Changing package version to: %s in WAPT\\control" % control.version)

    # Remove extract
    remove_tree(app_name)
